# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-20 23:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0026_auto_20170818_1123'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='slug_key',
            field=models.CharField(blank=True, help_text=b"Will be used, with package info, to generate additional items' slugs.", max_length=20, null=True),
        ),
    ]
