# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-24 19:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0031_auto_20170821_1251'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='printpublication',
            options={'ordering': ['priority', 'is_active', 'slug'], 'verbose_name': 'publishing destination'},
        ),
        migrations.AlterModelOptions(
            name='printsection',
            options={'ordering': ['priority', 'is_active', 'slug'], 'verbose_name': 'placement type'},
        ),
        migrations.AlterField(
            model_name='printsection',
            name='priority',
            field=models.PositiveSmallIntegerField(default=0, help_text='In the list of all active print publications, how high should this entry show up?'),
        ),
    ]
