# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-20 23:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0027_auto_20170820_1820'),
    ]

    operations = [
        migrations.AlterField(
            model_name='package',
            name='slug_key',
            field=models.CharField(help_text=b'Miniature package descriptor. Will be used to generate the slug.', max_length=25, null=True),
        ),
    ]
