// Roboto font
@if ($offline) {
    @import url(https://fonts.googleapis.com/css?family=Roboto:400,500,700,900,400italic);
    @import url(https://fonts.googleapis.com/css?family=Roboto+Mono);
} else {
    @import url(https://fonts.googleapis.com/css?family=Roboto:400,500,700,900,400italic);
    @import url(https://fonts.googleapis.com/css?family=Roboto+Mono);
}

// FontAwesome
$fa-font-path: "../fonts/font-awesome";
@import "../../node_modules/font-awesome/scss/font-awesome";


body {
    font-family: 'Roboto', sans-serif;

    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    p {
        font-family: 'Roboto', sans-serif;
    }
}
