# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-24 02:47
from __future__ import unicode_literals

import django.contrib.postgres.fields.ranges
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0009_auto_20160623_2139'),
    ]

    operations = [
        migrations.AddField(
            model_name='package',
            name='print_run_date',
            field=django.contrib.postgres.fields.ranges.DateRangeField(null=True),
        ),
    ]
