# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-08-18 00:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0024_auto_20160824_0945'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='item',
            options={'ordering': ['slug_key']},
        ),
        migrations.AddField(
            model_name='package',
            name='slug_key',
            field=models.CharField(help_text=b'Miniature package descriptor. Will be used to generate the slug.', max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='item',
            name='slug_key',
            field=models.CharField(help_text=b"Will be used, with package info, to generate additional items' slugs.", max_length=20),
        ),
    ]
