# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-28 17:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0018_auto_20160628_1037'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='length',
            field=models.PositiveIntegerField(blank=True, help_text=b'How long is this article?', null=True, verbose_name=b'Length (in words)'),
        ),
        migrations.AlterField(
            model_name='item',
            name='slug',
            field=models.CharField(db_index=True, editable=False, max_length=100, unique=True),
        ),
        migrations.AlterField(
            model_name='item',
            name='slug_key',
            field=models.CharField(help_text=b'Will be used, with package info, to generate the slug', max_length=20),
        ),
    ]
