<div class="accent-line-holder">
    <div class="double-line"></div>
</div>
<img class="the-daily" src="{{ printLogoURL }}" alt="The Daily" />
<div class="accent-line-holder">
    <div class="double-line"></div>
</div>
<div class="clearer"></div>
