<a href="{{ homeViewLink }}" class="">
    <img class="masthead" src="{{ mastheadLogoURL }}" alt="{{ mastheadLogoAltText }}" />
    <img class="budget-wordmark" src="{{ siteLogoURL }}" alt="{{ siteLogoAltText }}" />
</a>
